==> org.eclipse.papyrus.def.source_1.3.100.201806131019.jar: aspects/xpt/diagram/edithelpers/BaseEditHelper.java <==
/**
 * Copyright (c) 2017 CEA LIST.
 * 
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors:
 *  Benoit Maggi (CEA LIST) benoit.maggi@cea.fr - Initial API and implementation
 */
package aspects.xpt.diagram.edithelpers;

import org.eclipse.gmf.codegen.gmfgen.GenDiagram;
import org.eclipse.xtend2.lib.StringConcatenation;

@SuppressWarnings("all")
public class BaseEditHelper extends xpt.diagram.edithelpers.BaseEditHelper {
  @Override
  public CharSequence superClass(final GenDiagram it) {
    StringConcatenation _builder = new StringConcatenation();
    _builder.append("org.eclipse.papyrus.infra.gmfdiag.tooling.runtime.edit.helpers.GeneratedEditHelperBase");
    return _builder;
  }
  
  @Override
  public CharSequence editPolicyCommandConstant(final GenDiagram it) {
    StringConcatenation _builder = new StringConcatenation();
    _builder.append("org.eclipse.papyrus.infra.gmfdiag.tooling.runtime.edit.helpers.GeneratedEditHelperBase.EDIT_POLICY_COMMAND");
    return _builder;
  }
  
  @Override
  public CharSequence contextElementTypeConstant(final GenDiagram it) {
    StringConcatenation _builder = new StringConcatenation();
    _builder.append("org.eclipse.papyrus.infra.gmfdiag.tooling.runtime.edit.helpers.GeneratedEditHelperBase.CONTEXT_ELEMENT_TYPE");
    return _builder;
  }
}

==> org.eclipse.papyrus.def.source_2.1.0.202103101156.jar: aspects/xpt/diagram/edithelpers/BaseEditHelper.java <==
/**
 * Copyright (c) 2017 CEA LIST.
 * 
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License 2.0
 * which accompanies this distribution, and is available at
 * https://www.eclipse.org/legal/epl-2.0/
 * 
 * SPDX-License-Identifier: EPL-2.0
 * 
 * Contributors:
 * Benoit Maggi (CEA LIST) benoit.maggi@cea.fr - Initial API and implementation
 */
package aspects.xpt.diagram.edithelpers;

import org.eclipse.papyrus.gmf.codegen.gmfgen.GenDiagram;
import org.eclipse.xtend2.lib.StringConcatenation;

@SuppressWarnings("all")
public class BaseEditHelper extends xpt.diagram.edithelpers.BaseEditHelper {
  @Override
  public CharSequence superClass(final GenDiagram it) {
    StringConcatenation _builder = new StringConcatenation();
    _builder.append("org.eclipse.papyrus.infra.gmfdiag.tooling.runtime.edit.helpers.GeneratedEditHelperBase");
    return _builder;
  }
  
  @Override
  public CharSequence editPolicyCommandConstant(final GenDiagram it) {
    StringConcatenation _builder = new StringConcatenation();
    _builder.append("org.eclipse.papyrus.infra.gmfdiag.tooling.runtime.edit.helpers.GeneratedEditHelperBase.EDIT_POLICY_COMMAND");
    return _builder;
  }
  
  @Override
  public CharSequence contextElementTypeConstant(final GenDiagram it) {
    StringConcatenation _builder = new StringConcatenation();
    _builder.append("org.eclipse.papyrus.infra.gmfdiag.tooling.runtime.edit.helpers.GeneratedEditHelperBase.CONTEXT_ELEMENT_TYPE");
    return _builder;
  }
}
